.. _in_install:

Get Arbor
=========

- To take a sneak preview of Arbor right here in your browser, navigate to `the Arbor Playground <https://arbor-sim.org/playground>`_.
- To download and install Arbor on your system, enter ``pip install arbor`` in a terminal.
- Download a :ref:`in_gui`.

More and more advanced installation instructions (such as building Arbor with GPU or MPI support)
can be found below:

.. toctree::
   :maxdepth: 1

   playground
   gui
   python
   spack
   build_install
